//
// CollectionsAPI.swift
//
// Generated by swagger-codegen
// https://github.com/swagger-api/swagger-codegen
//

import Alamofire



public class CollectionsAPI: APIBase {
    /**
     Public Collection Articles
     
     - parameter collectionId: (path) Collection Unique identifier 
     - parameter page: (query) Page number. Used for pagination with page_size (optional)
     - parameter pageSize: (query) The number of results included on a page. Used for pagination with page (optional, default to 10)
     - parameter limit: (query) Number of results included on a page. Used for pagination with query (optional)
     - parameter offset: (query) Where to start the listing(the offset of the first result). Used for pagination with limit (optional)
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func collectionArticles(collectionId collectionId: Int64, page: Int64? = nil, pageSize: Int64? = nil, limit: Int64? = nil, offset: Int64? = nil, completion: ((data: [Article]?, error: ErrorType?) -> Void)) {
        collectionArticlesWithRequestBuilder(collectionId: collectionId, page: page, pageSize: pageSize, limit: limit, offset: offset).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Public Collection Articles
     - GET /collections/{collectionId}/articles
     - Returns a list of public collection articles
     - examples: [{contentType=application/json, example={}}]
     
     - parameter collectionId: (path) Collection Unique identifier 
     - parameter page: (query) Page number. Used for pagination with page_size (optional)
     - parameter pageSize: (query) The number of results included on a page. Used for pagination with page (optional, default to 10)
     - parameter limit: (query) Number of results included on a page. Used for pagination with query (optional)
     - parameter offset: (query) Where to start the listing(the offset of the first result). Used for pagination with limit (optional)

     - returns: RequestBuilder<[Article]> 
     */
    public class func collectionArticlesWithRequestBuilder(collectionId collectionId: Int64, page: Int64? = nil, pageSize: Int64? = nil, limit: Int64? = nil, offset: Int64? = nil) -> RequestBuilder<[Article]> {
        var path = "/collections/{collectionId}/articles"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [
            "page": page?.encodeToJSON(),
            "page_size": pageSize?.encodeToJSON(),
            "limit": limit?.encodeToJSON(),
            "offset": offset?.encodeToJSON()
        ]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<[Article]>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "GET", URLString: URLString, parameters: convertedParameters, isBody: false)
    }

    /**
     Collection details
     
     - parameter collectionId: (path) Collection Unique identifier 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func collectionDetails(collectionId collectionId: Int64, completion: ((data: CollectionComplete?, error: ErrorType?) -> Void)) {
        collectionDetailsWithRequestBuilder(collectionId: collectionId).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Collection details
     - GET /collections/{collectionId}
     - View a collection
     - examples: [{contentType=application/json, example={
  "blank": true,
  "bytes": [],
  "empty": true
}}]
     
     - parameter collectionId: (path) Collection Unique identifier 

     - returns: RequestBuilder<CollectionComplete> 
     */
    public class func collectionDetailsWithRequestBuilder(collectionId collectionId: Int64) -> RequestBuilder<CollectionComplete> {
        var path = "/collections/{collectionId}"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<CollectionComplete>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "GET", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Collection Version details
     
     - parameter collectionId: (path) Collection Unique identifier 
     - parameter versionId: (path) Version Number 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func collectionVersionDetails(collectionId collectionId: Int64, versionId: Int64, completion: ((data: CollectionComplete?, error: ErrorType?) -> Void)) {
        collectionVersionDetailsWithRequestBuilder(collectionId: collectionId, versionId: versionId).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Collection Version details
     - GET /collections/{collectionId}/versions/{versionId}
     - View details for a certain version of a collection
     - examples: [{contentType=application/json, example={
  "blank": true,
  "bytes": [],
  "empty": true
}}]
     
     - parameter collectionId: (path) Collection Unique identifier 
     - parameter versionId: (path) Version Number 

     - returns: RequestBuilder<CollectionComplete> 
     */
    public class func collectionVersionDetailsWithRequestBuilder(collectionId collectionId: Int64, versionId: Int64) -> RequestBuilder<CollectionComplete> {
        var path = "/collections/{collectionId}/versions/{versionId}"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        path = path.stringByReplacingOccurrencesOfString("{version_id}", withString: "\(versionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<CollectionComplete>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "GET", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Collection Versions list
     
     - parameter collectionId: (path) Collection Unique identifier 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func collectionVersions(collectionId collectionId: Int64, completion: ((data: [CollectionVersions]?, error: ErrorType?) -> Void)) {
        collectionVersionsWithRequestBuilder(collectionId: collectionId).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Collection Versions list
     - GET /collections/{collectionId}/versions
     - Returns a list of public collection Versions
     - examples: [{contentType=application/json, example={}}]
     
     - parameter collectionId: (path) Collection Unique identifier 

     - returns: RequestBuilder<[CollectionVersions]> 
     */
    public class func collectionVersionsWithRequestBuilder(collectionId collectionId: Int64) -> RequestBuilder<[CollectionVersions]> {
        var path = "/collections/{collectionId}/versions"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<[CollectionVersions]>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "GET", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     * enum for parameter order
     */
    public enum Order_collectionsList: String { 
        case PublishedDate = "published_date"
        case CreatedDate = "created_date"
        case ModifiedDate = "modified_date"
        case Views = "views"
        case Shares = "shares"
        case Cites = "cites"
    }

    /**
     * enum for parameter orderDirection
     */
    public enum OrderDirection_collectionsList: String { 
        case Asc = "asc"
        case Desc = "desc"
    }

    /**
     Public Collections
     
     - parameter xCursor: (header) Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)
     - parameter page: (query) Page number. Used for pagination with page_size (optional)
     - parameter pageSize: (query) The number of results included on a page. Used for pagination with page (optional, default to 10)
     - parameter limit: (query) Number of results included on a page. Used for pagination with query (optional)
     - parameter offset: (query) Where to start the listing(the offset of the first result). Used for pagination with limit (optional)
     - parameter order: (query) The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)
     - parameter orderDirection: (query)  (optional, default to desc)
     - parameter institution: (query) only return collections from this institution (optional)
     - parameter publishedSince: (query) Filter by collection publishing date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)
     - parameter modifiedSince: (query) Filter by collection modified date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)
     - parameter group: (query) only return collections from this group (optional)
     - parameter resourceDoi: (query) only return collections with this resource_doi (optional)
     - parameter doi: (query) only return collections with this doi (optional)
     - parameter handle: (query) only return collections with this handle (optional)
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func collectionsList(xCursor xCursor: NSUUID? = nil, page: Int64? = nil, pageSize: Int64? = nil, limit: Int64? = nil, offset: Int64? = nil, order: Order_collectionsList? = nil, orderDirection: OrderDirection_collectionsList? = nil, institution: Int64? = nil, publishedSince: String? = nil, modifiedSince: String? = nil, group: Int64? = nil, resourceDoi: String? = nil, doi: String? = nil, handle: String? = nil, completion: ((data: [Collection]?, error: ErrorType?) -> Void)) {
        collectionsListWithRequestBuilder(xCursor: xCursor, page: page, pageSize: pageSize, limit: limit, offset: offset, order: order, orderDirection: orderDirection, institution: institution, publishedSince: publishedSince, modifiedSince: modifiedSince, group: group, resourceDoi: resourceDoi, doi: doi, handle: handle).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Public Collections
     - GET /collections
     - Returns a list of public collections
     - responseHeaders: [X-Cursor(String)]
     - examples: [{contentType=application/json, example={}}]
     
     - parameter xCursor: (header) Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)
     - parameter page: (query) Page number. Used for pagination with page_size (optional)
     - parameter pageSize: (query) The number of results included on a page. Used for pagination with page (optional, default to 10)
     - parameter limit: (query) Number of results included on a page. Used for pagination with query (optional)
     - parameter offset: (query) Where to start the listing(the offset of the first result). Used for pagination with limit (optional)
     - parameter order: (query) The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)
     - parameter orderDirection: (query)  (optional, default to desc)
     - parameter institution: (query) only return collections from this institution (optional)
     - parameter publishedSince: (query) Filter by collection publishing date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)
     - parameter modifiedSince: (query) Filter by collection modified date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)
     - parameter group: (query) only return collections from this group (optional)
     - parameter resourceDoi: (query) only return collections with this resource_doi (optional)
     - parameter doi: (query) only return collections with this doi (optional)
     - parameter handle: (query) only return collections with this handle (optional)

     - returns: RequestBuilder<[Collection]> 
     */
    public class func collectionsListWithRequestBuilder(xCursor xCursor: NSUUID? = nil, page: Int64? = nil, pageSize: Int64? = nil, limit: Int64? = nil, offset: Int64? = nil, order: Order_collectionsList? = nil, orderDirection: OrderDirection_collectionsList? = nil, institution: Int64? = nil, publishedSince: String? = nil, modifiedSince: String? = nil, group: Int64? = nil, resourceDoi: String? = nil, doi: String? = nil, handle: String? = nil) -> RequestBuilder<[Collection]> {
        let path = "/collections"
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [
            "page": page?.encodeToJSON(),
            "page_size": pageSize?.encodeToJSON(),
            "limit": limit?.encodeToJSON(),
            "offset": offset?.encodeToJSON(),
            "order": order?.rawValue,
            "order_direction": orderDirection?.rawValue,
            "institution": institution?.encodeToJSON(),
            "published_since": publishedSince,
            "modified_since": modifiedSince,
            "group": group?.encodeToJSON(),
            "resource_doi": resourceDoi,
            "doi": doi,
            "handle": handle
        ]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
        let nillableHeaders: [String: AnyObject?] = [
            "X-Cursor": xCursor
        ]
        let headerParameters = APIHelper.rejectNilHeaders(nillableHeaders)
 
        let requestBuilder: RequestBuilder<[Collection]>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "GET", URLString: URLString, parameters: convertedParameters, isBody: false, headers: headerParameters)
    }

    /**
     Public Collections Search
     
     - parameter xCursor: (header) Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)
     - parameter search: (body) Search Parameters (optional)
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func collectionsSearch(xCursor xCursor: NSUUID? = nil, search: CollectionSearch? = nil, completion: ((data: [Collection]?, error: ErrorType?) -> Void)) {
        collectionsSearchWithRequestBuilder(xCursor: xCursor, search: search).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Public Collections Search
     - POST /collections/search
     - Returns a list of public collections
     - responseHeaders: [X-Cursor(String)]
     - examples: [{contentType=application/json, example={}}]
     
     - parameter xCursor: (header) Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)
     - parameter search: (body) Search Parameters (optional)

     - returns: RequestBuilder<[Collection]> 
     */
    public class func collectionsSearchWithRequestBuilder(xCursor xCursor: NSUUID? = nil, search: CollectionSearch? = nil) -> RequestBuilder<[Collection]> {
        let path = "/collections/search"
        let URLString = SwaggerClientAPI.basePath + path
        let parameters = search?.encodeToJSON() as? [String:AnyObject]
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
        let nillableHeaders: [String: AnyObject?] = [
            "X-Cursor": xCursor
        ]
        let headerParameters = APIHelper.rejectNilHeaders(nillableHeaders)
 
        let requestBuilder: RequestBuilder<[Collection]>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "POST", URLString: URLString, parameters: convertedParameters, isBody: true, headers: headerParameters)
    }

    /**
     Delete collection article
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter articleId: (path) Collection article unique identifier 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionArticleDelete(collectionId collectionId: Int64, articleId: Int64, completion: ((error: ErrorType?) -> Void)) {
        privateCollectionArticleDeleteWithRequestBuilder(collectionId: collectionId, articleId: articleId).execute { (response, error) -> Void in
            completion(error: error);
        }
    }


    /**
     Delete collection article
     - DELETE /account/collections/{collectionId}/articles/{articleId}
     - De-associate article from collection
     - OAuth:
       - type: oauth2
       - name: OAuth2
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter articleId: (path) Collection article unique identifier 

     - returns: RequestBuilder<Void> 
     */
    public class func privateCollectionArticleDeleteWithRequestBuilder(collectionId collectionId: Int64, articleId: Int64) -> RequestBuilder<Void> {
        var path = "/account/collections/{collectionId}/articles/{articleId}"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        path = path.stringByReplacingOccurrencesOfString("{article_id}", withString: "\(articleId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Void>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "DELETE", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Add collection articles
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter articles: (body) Articles list 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionArticlesAdd(collectionId collectionId: Int64, articles: ArticlesCreator, completion: ((data: Location?, error: ErrorType?) -> Void)) {
        privateCollectionArticlesAddWithRequestBuilder(collectionId: collectionId, articles: articles).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Add collection articles
     - POST /account/collections/{collectionId}/articles
     - Associate new articles with the collection. This will add new articles to the list of already associated articles
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - responseHeaders: [Location(String)]
     - examples: [{contentType=application/json, example={"empty": false}}]
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter articles: (body) Articles list 

     - returns: RequestBuilder<Location> 
     */
    public class func privateCollectionArticlesAddWithRequestBuilder(collectionId collectionId: Int64, articles: ArticlesCreator) -> RequestBuilder<Location> {
        var path = "/account/collections/{collectionId}/articles"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path
        let parameters = articles.encodeToJSON() as? [String:AnyObject]
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Location>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "POST", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     List collection articles
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter page: (query) Page number. Used for pagination with page_size (optional)
     - parameter pageSize: (query) The number of results included on a page. Used for pagination with page (optional, default to 10)
     - parameter limit: (query) Number of results included on a page. Used for pagination with query (optional)
     - parameter offset: (query) Where to start the listing(the offset of the first result). Used for pagination with limit (optional)
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionArticlesList(collectionId collectionId: Int64, page: Int64? = nil, pageSize: Int64? = nil, limit: Int64? = nil, offset: Int64? = nil, completion: ((data: [Article]?, error: ErrorType?) -> Void)) {
        privateCollectionArticlesListWithRequestBuilder(collectionId: collectionId, page: page, pageSize: pageSize, limit: limit, offset: offset).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     List collection articles
     - GET /account/collections/{collectionId}/articles
     - List collection articles
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - examples: [{contentType=application/json, example={}}]
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter page: (query) Page number. Used for pagination with page_size (optional)
     - parameter pageSize: (query) The number of results included on a page. Used for pagination with page (optional, default to 10)
     - parameter limit: (query) Number of results included on a page. Used for pagination with query (optional)
     - parameter offset: (query) Where to start the listing(the offset of the first result). Used for pagination with limit (optional)

     - returns: RequestBuilder<[Article]> 
     */
    public class func privateCollectionArticlesListWithRequestBuilder(collectionId collectionId: Int64, page: Int64? = nil, pageSize: Int64? = nil, limit: Int64? = nil, offset: Int64? = nil) -> RequestBuilder<[Article]> {
        var path = "/account/collections/{collectionId}/articles"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [
            "page": page?.encodeToJSON(),
            "page_size": pageSize?.encodeToJSON(),
            "limit": limit?.encodeToJSON(),
            "offset": offset?.encodeToJSON()
        ]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<[Article]>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "GET", URLString: URLString, parameters: convertedParameters, isBody: false)
    }

    /**
     Replace collection articles
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter articles: (body) Articles List 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionArticlesReplace(collectionId collectionId: Int64, articles: ArticlesCreator, completion: ((error: ErrorType?) -> Void)) {
        privateCollectionArticlesReplaceWithRequestBuilder(collectionId: collectionId, articles: articles).execute { (response, error) -> Void in
            completion(error: error);
        }
    }


    /**
     Replace collection articles
     - PUT /account/collections/{collectionId}/articles
     - Associate new articles with the collection. This will remove all already associated articles and add these new ones
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - responseHeaders: [Location(String)]
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter articles: (body) Articles List 

     - returns: RequestBuilder<Void> 
     */
    public class func privateCollectionArticlesReplaceWithRequestBuilder(collectionId collectionId: Int64, articles: ArticlesCreator) -> RequestBuilder<Void> {
        var path = "/account/collections/{collectionId}/articles"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path
        let parameters = articles.encodeToJSON() as? [String:AnyObject]
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Void>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "PUT", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Delete collection author
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter authorId: (path) Collection Author unique identifier 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionAuthorDelete(collectionId collectionId: Int64, authorId: Int64, completion: ((error: ErrorType?) -> Void)) {
        privateCollectionAuthorDeleteWithRequestBuilder(collectionId: collectionId, authorId: authorId).execute { (response, error) -> Void in
            completion(error: error);
        }
    }


    /**
     Delete collection author
     - DELETE /account/collections/{collectionId}/authors/{authorId}
     - Delete collection author
     - OAuth:
       - type: oauth2
       - name: OAuth2
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter authorId: (path) Collection Author unique identifier 

     - returns: RequestBuilder<Void> 
     */
    public class func privateCollectionAuthorDeleteWithRequestBuilder(collectionId collectionId: Int64, authorId: Int64) -> RequestBuilder<Void> {
        var path = "/account/collections/{collectionId}/authors/{authorId}"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        path = path.stringByReplacingOccurrencesOfString("{author_id}", withString: "\(authorId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Void>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "DELETE", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Add collection authors
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter authors: (body) List of authors 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionAuthorsAdd(collectionId collectionId: Int64, authors: AuthorsCreator, completion: ((data: Location?, error: ErrorType?) -> Void)) {
        privateCollectionAuthorsAddWithRequestBuilder(collectionId: collectionId, authors: authors).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Add collection authors
     - POST /account/collections/{collectionId}/authors
     - Associate new authors with the collection. This will add new authors to the list of already associated authors
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - responseHeaders: [Location(String)]
     - examples: [{contentType=application/json, example={"empty": false}}]
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter authors: (body) List of authors 

     - returns: RequestBuilder<Location> 
     */
    public class func privateCollectionAuthorsAddWithRequestBuilder(collectionId collectionId: Int64, authors: AuthorsCreator) -> RequestBuilder<Location> {
        var path = "/account/collections/{collectionId}/authors"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path
        let parameters = authors.encodeToJSON() as? [String:AnyObject]
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Location>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "POST", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     List collection authors
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionAuthorsList(collectionId collectionId: Int64, completion: ((data: [Author]?, error: ErrorType?) -> Void)) {
        privateCollectionAuthorsListWithRequestBuilder(collectionId: collectionId).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     List collection authors
     - GET /account/collections/{collectionId}/authors
     - List collection authors
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - examples: [{contentType=application/json, example={}}]
     
     - parameter collectionId: (path) Collection unique identifier 

     - returns: RequestBuilder<[Author]> 
     */
    public class func privateCollectionAuthorsListWithRequestBuilder(collectionId collectionId: Int64) -> RequestBuilder<[Author]> {
        var path = "/account/collections/{collectionId}/authors"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<[Author]>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "GET", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Replace collection authors
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter authors: (body) List of authors 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionAuthorsReplace(collectionId collectionId: Int64, authors: AuthorsCreator, completion: ((error: ErrorType?) -> Void)) {
        privateCollectionAuthorsReplaceWithRequestBuilder(collectionId: collectionId, authors: authors).execute { (response, error) -> Void in
            completion(error: error);
        }
    }


    /**
     Replace collection authors
     - PUT /account/collections/{collectionId}/authors
     - Associate new authors with the collection. This will remove all already associated authors and add these new ones
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - responseHeaders: [Location(String)]
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter authors: (body) List of authors 

     - returns: RequestBuilder<Void> 
     */
    public class func privateCollectionAuthorsReplaceWithRequestBuilder(collectionId collectionId: Int64, authors: AuthorsCreator) -> RequestBuilder<Void> {
        var path = "/account/collections/{collectionId}/authors"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path
        let parameters = authors.encodeToJSON() as? [String:AnyObject]
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Void>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "PUT", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Add collection categories
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter categories: (body) Categories list 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionCategoriesAdd(collectionId collectionId: Int64, categories: CategoriesCreator, completion: ((data: Location?, error: ErrorType?) -> Void)) {
        privateCollectionCategoriesAddWithRequestBuilder(collectionId: collectionId, categories: categories).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Add collection categories
     - POST /account/collections/{collectionId}/categories
     - Associate new categories with the collection. This will add new categories to the list of already associated categories
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - responseHeaders: [Location(String)]
     - examples: [{contentType=application/json, example={"empty": false}}]
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter categories: (body) Categories list 

     - returns: RequestBuilder<Location> 
     */
    public class func privateCollectionCategoriesAddWithRequestBuilder(collectionId collectionId: Int64, categories: CategoriesCreator) -> RequestBuilder<Location> {
        var path = "/account/collections/{collectionId}/categories"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path
        let parameters = categories.encodeToJSON() as? [String:AnyObject]
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Location>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "POST", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     List collection categories
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionCategoriesList(collectionId collectionId: Int64, completion: ((data: [Category]?, error: ErrorType?) -> Void)) {
        privateCollectionCategoriesListWithRequestBuilder(collectionId: collectionId).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     List collection categories
     - GET /account/collections/{collectionId}/categories
     - List collection categories
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - examples: [{contentType=application/json, example={}}]
     
     - parameter collectionId: (path) Collection unique identifier 

     - returns: RequestBuilder<[Category]> 
     */
    public class func privateCollectionCategoriesListWithRequestBuilder(collectionId collectionId: Int64) -> RequestBuilder<[Category]> {
        var path = "/account/collections/{collectionId}/categories"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<[Category]>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "GET", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Replace collection categories
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter categories: (body) Categories list 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionCategoriesReplace(collectionId collectionId: Int64, categories: CategoriesCreator, completion: ((error: ErrorType?) -> Void)) {
        privateCollectionCategoriesReplaceWithRequestBuilder(collectionId: collectionId, categories: categories).execute { (response, error) -> Void in
            completion(error: error);
        }
    }


    /**
     Replace collection categories
     - PUT /account/collections/{collectionId}/categories
     - Associate new categories with the collection. This will remove all already associated categories and add these new ones
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - responseHeaders: [Location(String)]
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter categories: (body) Categories list 

     - returns: RequestBuilder<Void> 
     */
    public class func privateCollectionCategoriesReplaceWithRequestBuilder(collectionId collectionId: Int64, categories: CategoriesCreator) -> RequestBuilder<Void> {
        var path = "/account/collections/{collectionId}/categories"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path
        let parameters = categories.encodeToJSON() as? [String:AnyObject]
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Void>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "PUT", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Delete collection category
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter categoryId: (path) Collection category unique identifier 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionCategoryDelete(collectionId collectionId: Int64, categoryId: Int64, completion: ((error: ErrorType?) -> Void)) {
        privateCollectionCategoryDeleteWithRequestBuilder(collectionId: collectionId, categoryId: categoryId).execute { (response, error) -> Void in
            completion(error: error);
        }
    }


    /**
     Delete collection category
     - DELETE /account/collections/{collectionId}/categories/{categoryId}
     - De-associate category from collection
     - OAuth:
       - type: oauth2
       - name: OAuth2
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter categoryId: (path) Collection category unique identifier 

     - returns: RequestBuilder<Void> 
     */
    public class func privateCollectionCategoryDeleteWithRequestBuilder(collectionId collectionId: Int64, categoryId: Int64) -> RequestBuilder<Void> {
        var path = "/account/collections/{collectionId}/categories/{categoryId}"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        path = path.stringByReplacingOccurrencesOfString("{category_id}", withString: "\(categoryId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Void>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "DELETE", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Create collection
     
     - parameter collection: (body) Collection description 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionCreate(collection collection: CollectionCreate, completion: ((data: LocationWarnings?, error: ErrorType?) -> Void)) {
        privateCollectionCreateWithRequestBuilder(collection: collection).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Create collection
     - POST /account/collections
     - Create a new Collection by sending collection information
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - examples: [{contentType=application/json, example={"empty": false}}]
     
     - parameter collection: (body) Collection description 

     - returns: RequestBuilder<LocationWarnings> 
     */
    public class func privateCollectionCreateWithRequestBuilder(collection collection: CollectionCreate) -> RequestBuilder<LocationWarnings> {
        let path = "/account/collections"
        let URLString = SwaggerClientAPI.basePath + path
        let parameters = collection.encodeToJSON() as? [String:AnyObject]
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<LocationWarnings>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "POST", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Delete collection
     
     - parameter collectionId: (path) Collection Unique identifier 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionDelete(collectionId collectionId: Int64, completion: ((error: ErrorType?) -> Void)) {
        privateCollectionDeleteWithRequestBuilder(collectionId: collectionId).execute { (response, error) -> Void in
            completion(error: error);
        }
    }


    /**
     Delete collection
     - DELETE /account/collections/{collectionId}
     - Delete n collection
     - OAuth:
       - type: oauth2
       - name: OAuth2
     
     - parameter collectionId: (path) Collection Unique identifier 

     - returns: RequestBuilder<Void> 
     */
    public class func privateCollectionDeleteWithRequestBuilder(collectionId collectionId: Int64) -> RequestBuilder<Void> {
        var path = "/account/collections/{collectionId}"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Void>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "DELETE", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Collection details
     
     - parameter collectionId: (path) Collection Unique identifier 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionDetails(collectionId collectionId: Int64, completion: ((data: CollectionCompletePrivate?, error: ErrorType?) -> Void)) {
        privateCollectionDetailsWithRequestBuilder(collectionId: collectionId).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Collection details
     - GET /account/collections/{collectionId}
     - View a collection
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - examples: [{contentType=application/json, example={
  "blank": true,
  "bytes": [],
  "empty": true
}}]
     
     - parameter collectionId: (path) Collection Unique identifier 

     - returns: RequestBuilder<CollectionCompletePrivate> 
     */
    public class func privateCollectionDetailsWithRequestBuilder(collectionId collectionId: Int64) -> RequestBuilder<CollectionCompletePrivate> {
        var path = "/account/collections/{collectionId}"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<CollectionCompletePrivate>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "GET", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Create collection private link
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter privateLink: (body)  (optional)
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionPrivateLinkCreate(collectionId collectionId: Int64, privateLink: CollectionPrivateLinkCreator? = nil, completion: ((data: PrivateLinkResponse?, error: ErrorType?) -> Void)) {
        privateCollectionPrivateLinkCreateWithRequestBuilder(collectionId: collectionId, privateLink: privateLink).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Create collection private link
     - POST /account/collections/{collectionId}/private_links
     - Create new private link
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - responseHeaders: [Location(String)]
     - examples: [{contentType=application/json, example={"empty": false}}]
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter privateLink: (body)  (optional)

     - returns: RequestBuilder<PrivateLinkResponse> 
     */
    public class func privateCollectionPrivateLinkCreateWithRequestBuilder(collectionId collectionId: Int64, privateLink: CollectionPrivateLinkCreator? = nil) -> RequestBuilder<PrivateLinkResponse> {
        var path = "/account/collections/{collectionId}/private_links"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path
        let parameters = privateLink?.encodeToJSON() as? [String:AnyObject]
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<PrivateLinkResponse>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "POST", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Disable private link
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter linkId: (path) Private link token 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionPrivateLinkDelete(collectionId collectionId: Int64, linkId: String, completion: ((error: ErrorType?) -> Void)) {
        privateCollectionPrivateLinkDeleteWithRequestBuilder(collectionId: collectionId, linkId: linkId).execute { (response, error) -> Void in
            completion(error: error);
        }
    }


    /**
     Disable private link
     - DELETE /account/collections/{collectionId}/private_links/{linkId}
     - Disable/delete private link for this collection
     - OAuth:
       - type: oauth2
       - name: OAuth2
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter linkId: (path) Private link token 

     - returns: RequestBuilder<Void> 
     */
    public class func privateCollectionPrivateLinkDeleteWithRequestBuilder(collectionId collectionId: Int64, linkId: String) -> RequestBuilder<Void> {
        var path = "/account/collections/{collectionId}/private_links/{linkId}"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        path = path.stringByReplacingOccurrencesOfString("{link_id}", withString: "\(linkId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Void>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "DELETE", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Update collection private link
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter linkId: (path) Private link token 
     - parameter privateLink: (body)  (optional)
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionPrivateLinkUpdate(collectionId collectionId: Int64, linkId: String, privateLink: CollectionPrivateLinkCreator? = nil, completion: ((error: ErrorType?) -> Void)) {
        privateCollectionPrivateLinkUpdateWithRequestBuilder(collectionId: collectionId, linkId: linkId, privateLink: privateLink).execute { (response, error) -> Void in
            completion(error: error);
        }
    }


    /**
     Update collection private link
     - PUT /account/collections/{collectionId}/private_links/{linkId}
     - Update existing private link for this collection
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - responseHeaders: [Location(String)]
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter linkId: (path) Private link token 
     - parameter privateLink: (body)  (optional)

     - returns: RequestBuilder<Void> 
     */
    public class func privateCollectionPrivateLinkUpdateWithRequestBuilder(collectionId collectionId: Int64, linkId: String, privateLink: CollectionPrivateLinkCreator? = nil) -> RequestBuilder<Void> {
        var path = "/account/collections/{collectionId}/private_links/{linkId}"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        path = path.stringByReplacingOccurrencesOfString("{link_id}", withString: "\(linkId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path
        let parameters = privateLink?.encodeToJSON() as? [String:AnyObject]
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Void>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "PUT", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     List collection private links
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionPrivateLinksList(collectionId collectionId: Int64, completion: ((data: [PrivateLink]?, error: ErrorType?) -> Void)) {
        privateCollectionPrivateLinksListWithRequestBuilder(collectionId: collectionId).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     List collection private links
     - GET /account/collections/{collectionId}/private_links
     - List article private links
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - examples: [{contentType=application/json, example={}}]
     
     - parameter collectionId: (path) Collection unique identifier 

     - returns: RequestBuilder<[PrivateLink]> 
     */
    public class func privateCollectionPrivateLinksListWithRequestBuilder(collectionId collectionId: Int64) -> RequestBuilder<[PrivateLink]> {
        var path = "/account/collections/{collectionId}/private_links"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<[PrivateLink]>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "GET", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Private Collection Publish
     
     - parameter collectionId: (path) Collection Unique identifier 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionPublish(collectionId collectionId: Int64, completion: ((data: Location?, error: ErrorType?) -> Void)) {
        privateCollectionPublishWithRequestBuilder(collectionId: collectionId).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Private Collection Publish
     - POST /account/collections/{collectionId}/publish
     - When a collection is published, a new public version will be generated. Any further updates to the collection will affect the private collection data. In order to make these changes publicly visible, an explicit publish operation is needed.
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - responseHeaders: [Location(String)]
     - examples: [{contentType=application/json, example={"empty": false}}]
     
     - parameter collectionId: (path) Collection Unique identifier 

     - returns: RequestBuilder<Location> 
     */
    public class func privateCollectionPublishWithRequestBuilder(collectionId collectionId: Int64) -> RequestBuilder<Location> {
        var path = "/account/collections/{collectionId}/publish"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Location>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "POST", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Private Collection Reserve DOI
     
     - parameter collectionId: (path) Collection Unique identifier 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionReserveDoi(collectionId collectionId: Int64, completion: ((data: CollectionDOI?, error: ErrorType?) -> Void)) {
        privateCollectionReserveDoiWithRequestBuilder(collectionId: collectionId).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Private Collection Reserve DOI
     - POST /account/collections/{collectionId}/reserve_doi
     - Reserve DOI for collection
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - examples: [{contentType=application/json, example={"empty": false}}]
     
     - parameter collectionId: (path) Collection Unique identifier 

     - returns: RequestBuilder<CollectionDOI> 
     */
    public class func privateCollectionReserveDoiWithRequestBuilder(collectionId collectionId: Int64) -> RequestBuilder<CollectionDOI> {
        var path = "/account/collections/{collectionId}/reserve_doi"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<CollectionDOI>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "POST", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Private Collection Reserve Handle
     
     - parameter collectionId: (path) Collection Unique identifier 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionReserveHandle(collectionId collectionId: Int64, completion: ((data: CollectionHandle?, error: ErrorType?) -> Void)) {
        privateCollectionReserveHandleWithRequestBuilder(collectionId: collectionId).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Private Collection Reserve Handle
     - POST /account/collections/{collectionId}/reserve_handle
     - Reserve Handle for collection
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - examples: [{contentType=application/json, example={"empty": false}}]
     
     - parameter collectionId: (path) Collection Unique identifier 

     - returns: RequestBuilder<CollectionHandle> 
     */
    public class func privateCollectionReserveHandleWithRequestBuilder(collectionId collectionId: Int64) -> RequestBuilder<CollectionHandle> {
        var path = "/account/collections/{collectionId}/reserve_handle"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [:]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<CollectionHandle>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "POST", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Private Collection Resource
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter resource: (body) Resource data 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionResource(collectionId collectionId: Int64, resource: Resource, completion: ((data: Location?, error: ErrorType?) -> Void)) {
        privateCollectionResourceWithRequestBuilder(collectionId: collectionId, resource: resource).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Private Collection Resource
     - POST /account/collections/{collectionId}/resource
     - Edit collection resource data.
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - responseHeaders: [Location(String)]
     - examples: [{contentType=application/json, example={"empty": false}}]
     
     - parameter collectionId: (path) Collection unique identifier 
     - parameter resource: (body) Resource data 

     - returns: RequestBuilder<Location> 
     */
    public class func privateCollectionResourceWithRequestBuilder(collectionId collectionId: Int64, resource: Resource) -> RequestBuilder<Location> {
        var path = "/account/collections/{collectionId}/resource"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path
        let parameters = resource.encodeToJSON() as? [String:AnyObject]
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<Location>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "POST", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     Update collection
     
     - parameter collectionId: (path) Collection Unique identifier 
     - parameter collection: (body) Collection description 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionUpdate(collectionId collectionId: Int64, collection: CollectionUpdate, completion: ((data: LocationWarningsUpdate?, error: ErrorType?) -> Void)) {
        privateCollectionUpdateWithRequestBuilder(collectionId: collectionId, collection: collection).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Update collection
     - PUT /account/collections/{collectionId}
     - Update collection details; request can also be made with the PATCH method.
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - responseHeaders: [Location(String)]
     - examples: [{contentType=application/json, example={"empty": false}}]
     
     - parameter collectionId: (path) Collection Unique identifier 
     - parameter collection: (body) Collection description 

     - returns: RequestBuilder<LocationWarningsUpdate> 
     */
    public class func privateCollectionUpdateWithRequestBuilder(collectionId collectionId: Int64, collection: CollectionUpdate) -> RequestBuilder<LocationWarningsUpdate> {
        var path = "/account/collections/{collectionId}"
        path = path.stringByReplacingOccurrencesOfString("{collection_id}", withString: "\(collectionId)", options: .LiteralSearch, range: nil)
        let URLString = SwaggerClientAPI.basePath + path
        let parameters = collection.encodeToJSON() as? [String:AnyObject]
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<LocationWarningsUpdate>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "PUT", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

    /**
     * enum for parameter order
     */
    public enum Order_privateCollectionsList: String { 
        case PublishedDate = "published_date"
        case ModifiedDate = "modified_date"
        case Views = "views"
        case Shares = "shares"
        case Cites = "cites"
    }

    /**
     * enum for parameter orderDirection
     */
    public enum OrderDirection_privateCollectionsList: String { 
        case Asc = "asc"
        case Desc = "desc"
    }

    /**
     Private Collections List
     
     - parameter page: (query) Page number. Used for pagination with page_size (optional)
     - parameter pageSize: (query) The number of results included on a page. Used for pagination with page (optional, default to 10)
     - parameter limit: (query) Number of results included on a page. Used for pagination with query (optional)
     - parameter offset: (query) Where to start the listing(the offset of the first result). Used for pagination with limit (optional)
     - parameter order: (query) The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)
     - parameter orderDirection: (query)  (optional, default to desc)
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionsList(page page: Int64? = nil, pageSize: Int64? = nil, limit: Int64? = nil, offset: Int64? = nil, order: Order_privateCollectionsList? = nil, orderDirection: OrderDirection_privateCollectionsList? = nil, completion: ((data: [Collection]?, error: ErrorType?) -> Void)) {
        privateCollectionsListWithRequestBuilder(page: page, pageSize: pageSize, limit: limit, offset: offset, order: order, orderDirection: orderDirection).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Private Collections List
     - GET /account/collections
     - List private collections
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - examples: [{contentType=application/json, example={}}]
     
     - parameter page: (query) Page number. Used for pagination with page_size (optional)
     - parameter pageSize: (query) The number of results included on a page. Used for pagination with page (optional, default to 10)
     - parameter limit: (query) Number of results included on a page. Used for pagination with query (optional)
     - parameter offset: (query) Where to start the listing(the offset of the first result). Used for pagination with limit (optional)
     - parameter order: (query) The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)
     - parameter orderDirection: (query)  (optional, default to desc)

     - returns: RequestBuilder<[Collection]> 
     */
    public class func privateCollectionsListWithRequestBuilder(page page: Int64? = nil, pageSize: Int64? = nil, limit: Int64? = nil, offset: Int64? = nil, order: Order_privateCollectionsList? = nil, orderDirection: OrderDirection_privateCollectionsList? = nil) -> RequestBuilder<[Collection]> {
        let path = "/account/collections"
        let URLString = SwaggerClientAPI.basePath + path

        let nillableParameters: [String:AnyObject?] = [
            "page": page?.encodeToJSON(),
            "page_size": pageSize?.encodeToJSON(),
            "limit": limit?.encodeToJSON(),
            "offset": offset?.encodeToJSON(),
            "order": order?.rawValue,
            "order_direction": orderDirection?.rawValue
        ]
 
        let parameters = APIHelper.rejectNil(nillableParameters)
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<[Collection]>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "GET", URLString: URLString, parameters: convertedParameters, isBody: false)
    }

    /**
     Private Collections Search
     
     - parameter search: (body) Search Parameters 
     - parameter completion: completion handler to receive the data and the error objects
     */
    public class func privateCollectionsSearch(search search: PrivateCollectionSearch, completion: ((data: [Collection]?, error: ErrorType?) -> Void)) {
        privateCollectionsSearchWithRequestBuilder(search: search).execute { (response, error) -> Void in
            completion(data: response?.body, error: error);
        }
    }


    /**
     Private Collections Search
     - POST /account/collections/search
     - Returns a list of private Collections
     - OAuth:
       - type: oauth2
       - name: OAuth2
     - examples: [{contentType=application/json, example={}}]
     
     - parameter search: (body) Search Parameters 

     - returns: RequestBuilder<[Collection]> 
     */
    public class func privateCollectionsSearchWithRequestBuilder(search search: PrivateCollectionSearch) -> RequestBuilder<[Collection]> {
        let path = "/account/collections/search"
        let URLString = SwaggerClientAPI.basePath + path
        let parameters = search.encodeToJSON() as? [String:AnyObject]
 
        let convertedParameters = APIHelper.convertBoolToString(parameters)
 
        let requestBuilder: RequestBuilder<[Collection]>.Type = SwaggerClientAPI.requestBuilderFactory.getBuilder()

        return requestBuilder.init(method: "POST", URLString: URLString, parameters: convertedParameters, isBody: true)
    }

}
